@@ -168,7 +168,7 @@
 typedef struct
 {
     uint8_t svid;
-    int16_t snr;		// 0 - 0xffff
+    uint16_t snr;		// 0 - 0xffff
     uint8_t elev;
     uint16_t azmth;
     uint8_t status;		// bit 0, has ephemeris, 1, has diff correction
@@ -530,12 +530,13 @@ gps_mask_t PrintSERPacket(struct gps_device_t *session, unsigned char pkt_id,
 	gpsd_report(LOG_PROG, "Garmin: SAT Data Sz: %d\n", pkt_len);
 	sats = (cpo_sat_data *) buf;
 
+	session->gpsdata.satellites_visible = 0;
 	session->gpsdata.satellites_used = 0;
 	memset(session->gpsdata.used, 0, sizeof(session->gpsdata.used));
 	gpsd_zero_satellites(&session->gpsdata);
 	for (i = 0, j = 0; i < GARMIN_CHANNELS; i++, sats++) {
 	    gpsd_report(LOG_INF,
-			"Garmin:   Sat %3d, snr: %5d, elev: %2d, Azmth: %3d, Stat: %x\n",
+			"Garmin:   Sat %3d, snr: %5u, elev: %2d, Azmth: %3d, Stat: %x\n",
 			sats->svid, GPSD_LE16TOH(sats->snr), sats->elev, 
 			GPSD_LE16TOH(sats->azmth),
 			sats->status);
@@ -546,14 +547,17 @@ gps_mask_t PrintSERPacket(struct gps_device_t *session, unsigned char pkt_id,
 		continue;
 	    }
 
-	    session->gpsdata.PRN[j] = (int)sats->svid;
+	    if ((int)sats->svid <= 32)
+		session->gpsdata.PRN[j] = (int)sats->svid;	/* GPS */
+	    else
+		session->gpsdata.PRN[j] = (int)sats->svid + 87;	/* SBAS */
 	    session->gpsdata.azimuth[j] = (int)GPSD_LE16TOH(sats->azmth);
 	    session->gpsdata.elevation[j] = (int)sats->elev;
 	    // Garmin does not document this.  snr is in dB*100
 	    // Known, but not seen satellites have a dB value of -1*100
 	    session->gpsdata.ss[j] = (float)(GPSD_LE16TOH(sats->snr) / 100.0);
-	    if (session->gpsdata.ss[j] < 0.0) {
-		session->gpsdata.ss[j] = 0.0;
+	    if (session->gpsdata.ss[j] == -1) {
+		continue;
 	    }
 	    // FIX-ME: Garmin documents this, but Daniel Dorau
 	    // <daniel.dorau@gmx.de> says the behavior on his GPSMap60CSX
@@ -561,14 +565,17 @@ gps_mask_t PrintSERPacket(struct gps_device_t *session, unsigned char pkt_id,
 	    if ((uint8_t) 0 != (sats->status & 4)) {
 		// used in solution?
 		session->gpsdata.used[session->gpsdata.satellites_used++]
-		    = (int)sats->svid;
+		    = session->gpsdata.PRN[j];
 	    }
 	    session->gpsdata.satellites_visible++;
 	    j++;
 
 	}
 	session->gpsdata.skyview_time = NAN;
-	mask |= SATELLITE_SET | USED_IS;
+	if (session->gpsdata.satellites_visible > 0)
+	    mask |= SATELLITE_SET;
+	if (session->gpsdata.satellites_used > 0)
+	    mask |= USED_IS;
 	gpsd_report(LOG_DATA,
 		    "Garmin: SAT_DATA: visible=%d used=%d\n",
 		    session->gpsdata.satellites_visible,
@@ -845,7 +852,7 @@ static bool is_usb_device(const char *path UNUSED, int vendor, int product)
 		    libusb_get_device_address(dev));
 
 	/* we match if vendor and product ID are right */
-	if (desc.idVendor == 0x91e && desc.idProduct == 3) {
+	if (desc.idVendor == (uint16_t)vendor && desc.idProduct == (uint16_t)product) {
 	    found = true;
 	    break;
 	}
