@@ -227,6 +227,14 @@ ubx_msg_nav_svinfo(struct gps_device_t *session, unsigned char *buf,
 	/*@ +predboolothers */
 	j++;
     }
+    /* mark SBAS sats in use if SBAS was in use as of the last MID 27 */
+    for (i = 0; i < j; i++) {
+	int prn = session->gpsdata.PRN[i];
+	if (DGPS_PRN(prn) \
+		&& session->gpsdata.status == STATUS_DGPS_FIX \
+		&& session->driver.sirf.dgps_source == SIRF_DGPS_SOURCE_SBAS)
+	    session->gpsdata.used[session->gpsdata.satellites_used++] = prn;
+    }
     session->gpsdata.skyview_time = NAN;
     session->gpsdata.satellites_visible = (int)st;
     session->gpsdata.satellites_used = (int)nsv;
@@ -537,10 +545,11 @@ bool ubx_write(struct gps_device_t * session,
 	CK_B += CK_A;
     }
     /*@ -nullderef @*/
-    for (i = 0; i < data_len; i++) {
-	CK_A += msg[i];
-	CK_B += CK_A;
-    }
+    if (msg != NULL)
+	for (i = 0; i < data_len; i++) {
+	    CK_A += msg[i];
+	    CK_B += CK_A;
+	}
 
     session->msgbuf[6 + data_len] = CK_A;
     session->msgbuf[7 + data_len] = CK_B;
