@@ -21,7 +21,8 @@ class gpscommon:
         self.sock = None        # in case we blow up in connect
         self.linebuffer = ""
         self.verbose = verbose
-        self.connect(host, port)
+        if host != None:
+            self.connect(host, port)
 
     def connect(self, host, port):
         """Connect to a host on a given port.
@@ -144,7 +145,7 @@ class gpsjson(gpscommon):
         if hasattr(self.data, "satellites"):
             self.data.satellites = map(lambda x: dictwrapper(x), self.data.satellites)
 
-    def stream(self, flags=0, outfile=None):
+    def stream(self, flags=0, devpath=None):
         "Control streaming reports from the daemon,"
         if flags & WATCH_DISABLE:
             arg = '?WATCH={"enable":false'
@@ -159,7 +160,7 @@ class gpsjson(gpscommon):
             if flags & WATCH_SCALED:
                 arg += ',"scaled":false'
             if flags & WATCH_TIMING:
-                arg += ',"scaled":false'
+                arg += ',"timing":false'
         else: # flags & WATCH_ENABLE:
             arg = '?WATCH={"enable":true'
             if flags & WATCH_JSON:
@@ -173,9 +174,9 @@ class gpsjson(gpscommon):
             if flags & WATCH_SCALED:
                 arg += ',"scaled":true'
             if flags & WATCH_TIMING:
-                arg += ',"scaled":true'
+                arg += ',"timing":true'
             if flags & WATCH_DEVICE:
-                arg += ',"device":"%s"' % outfile
+                arg += ',"device":"%s"' % devpath
         return self.send(arg + "}")
 
 class dictwrapper:
