@@ -64,7 +64,7 @@ To allow for adding and removing clients while the test is running,
 run in threaded mode by calling the start() method.  This simply calls
 the run method in a subthread, with locking of critical regions.
 """
-import sys, os, time, signal, pty, termios # fcntl, array, struct
+import os, time, signal, pty, termios # fcntl, array, struct
 import exceptions, threading, socket
 import gps
 import packet as sniffer
@@ -115,8 +115,8 @@ class TestLoad:
         #gps.packet.register_report(reporter)
         type_latch = None
         while True:
-            (len, ptype, packet, counter) = getter.get(logfp.fileno())
-            if len <= 0:
+            (plen, ptype, packet, counter) = getter.get(logfp.fileno())
+            if plen <= 0:
                 break
             elif ptype == sniffer.COMMENT_PACKET:
                 # Some comments are magic
@@ -173,6 +173,10 @@ class FakeGPS:
         self.index = 0
         self.progress("gpsfake: %s provides %d sentences\n" % (self.testload.name, len(self.testload.sentences)))
 
+    def write(self, line):
+        "Throw an error if this superclass is ever instantiated."
+        raise ValueError, line
+
     def feed(self):
         "Feed a line from the contents of the GPS log to the daemon."
         line = self.testload.sentences[self.index % len(self.testload.sentences)]
@@ -296,11 +300,12 @@ class DaemonInstance:
     def __init__(self, control_socket=None):
         self.sockfile = None
         self.pid = None
+        self.tmpdir = os.environ.get('TMPDIR', '/tmp')
         if control_socket:
             self.control_socket = control_socket
         else:
-            self.control_socket = "/tmp/gpsfake-%d.sock" % os.getpid()
-        self.pidfile  = "/tmp/gpsfake_pid-%s" % os.getpid()
+            self.control_socket = "%s/gpsfake-%d.sock" % (self.tmpdir, os.getpid())
+        self.pidfile = "%s/gpsfake-%d.pid" % (self.tmpdir, os.getpid())
     def spawn(self, options, port, background=False, prefix=""):
         "Spawn a daemon instance."
         self.spawncmd = None
@@ -429,7 +434,7 @@ class TestSession:
         self.threadlock = None
     def spawn(self):
         for sig in (signal.SIGQUIT, signal.SIGINT, signal.SIGTERM):
-            signal.signal(sig, lambda signal, frame: self.cleanup())
+            signal.signal(sig, lambda unused, dummy: self.cleanup())
         self.daemon.spawn(background=True, prefix=self.prefix, port=self.port, options=self.options)
         self.daemon.wait_pid()
     def set_predicate(self, pred):
@@ -491,8 +496,6 @@ class TestSession:
         self.progress("gpsfake: gather(%d)\n" % seconds)
         #mark = time.time()
         time.sleep(seconds)
-        #if self.timings.c_recv_time <= mark:
-        #    TestSessionError("no sentences received\n")
     def cleanup(self):
         "We're done, kill the daemon."
         self.progress("gpsfake: cleanup()\n")
