@@ -269,6 +269,24 @@ int ntpshm_put(struct gps_device_t *session, double fixtime, double fudge)
 }
 
 #ifdef PPS_ENABLE
+/*
+ * Possible pins for PPS: DCD, CTS, RTS, RI. Pinouts:
+ *
+ * DB9  DB25  Name      Full name
+ * ---  ----  ----      --------------------
+ *  3     2    TXD  --> Transmit Data
+ *  2     3    RXD  <-- Receive Data
+ *  7     4    RTS  --> Request To Send
+ *  8     5    CTS  <-- Clear To Send
+ *  6     6    DSR  <-- Data Set Ready
+ *  4    20    DTR  --> Data Terminal Ready
+ *  1     8    DCD  <-- Data Carrier Detect
+ *  9    22    RI   <-- Ring Indicator
+ *  5     7    SG       Signal ground 
+ */
+#include "pps_pin.h"
+
+/*@unused@*//* splint is confused here */
 /* put NTP shared memory info based on received PPS pulse
  *
  * good news is that kernel PPS gives us nSec resolution
@@ -337,7 +355,7 @@ static int ntpshm_pps(struct gps_device_t *session, struct timeval *tv)
     shmTimeP->receiveTimeStampSec = (time_t) tv->tv_sec;
     shmTimeP->receiveTimeStampUSec = (int)tv->tv_usec;
     /* precision is a placebo, ntpd does not really use it
-     * real world accuracty is around 16uS, thus -16 precision */
+     * real world accuracy is around 16uS, thus -16 precision */
     shmTimeP->precision = -16;
     shmTimeP->count++;
     shmTimeP->valid = 1;
@@ -406,7 +424,7 @@ static int ntpshm_pps(struct gps_device_t *session, struct timeval *tv)
 	} \
     } while (0)
 
-/* convert timeval to timespec, with rounding */
+/* convert timespec to timeval, with rounding */
 #define TSTOTV(tv, ts) \
     do { \
 	(tv)->tv_sec = (ts)->tv_sec; \
@@ -414,7 +432,7 @@ static int ntpshm_pps(struct gps_device_t *session, struct timeval *tv)
         TV_NORM( tv ); \
     } while (0)
 
-/* convert timespec to timeval */
+/* convert timeval to timespec */
 #define TVTOTS(ts, tv) \
     do { \
 	(ts)->tv_sec = (tv)->tv_sec; \
@@ -535,13 +553,6 @@ static /*@null@*/ void *gpsd_ppsmonitor(void *arg)
     struct timeval  tv;
     struct timespec ts;
     struct timeval pulse[2] = { {0, 0}, {0, 0} };
-#if defined(PPS_ON_CTS_ENABLE)
-    int pps_device = TIOCM_CTS;
-#define pps_device_str "CTS"
-#else
-    int pps_device = TIOCM_CAR;
-#define pps_device_str "DCD"
-#endif
 #if defined(HAVE_SYS_TIMEPPS_H)
     int kpps_edge = 0;       /* 0 = clear edge, 1 = assert edge */
     int cycle_kpps, duration_kpps;
@@ -610,22 +621,24 @@ static /*@null@*/ void *gpsd_ppsmonitor(void *arg)
     /* root privileges are not required after this point */
 
     /* wait for status change on the device's carrier-detect line */
-    while (ioctl(session->gpsdata.gps_fd, TIOCMIWAIT, pps_device) == 0) {
+    while (ioctl(session->gpsdata.gps_fd, TIOCMIWAIT, PPS_LINE_TIOC) == 0) {
 	int ok = 0;
 	char *log = NULL;
 
-#ifdef HAVE_LIBRT
+#ifdef HAVE_CLOCK_GETTIME
 	/* using  clock_gettime() here, that is nSec, 
 	 * not uSec like gettimeofday */
 	if ( 0 > clock_gettime(CLOCK_REALTIME, &ts) ) {
 	    /* uh, oh, can not get time! */
-	    continue;
+	    gpsd_report(LOG_ERROR, "PPS clock_gettime() failed\n");
+	    break;
 	}
 	TSTOTV( &tv, &ts);
 #else
 	if ( 0 > gettimeofday(&tv, NULL) ) {
 	    /* uh, oh, can not get time! */
-	    continue;
+	    gpsd_report(LOG_ERROR, "PPS gettimeofday() failed\n");
+	    break;
 	}
 	TVTOTS( &ts, &tv);
 #endif
@@ -654,7 +667,7 @@ static /*@null@*/ void *gpsd_ppsmonitor(void *arg)
 		    kpps_edge = 0;
 		    tv_kpps = pi.clear_timestamp;
 		}
-		gpsd_report(LOG_PROG, "assert %ld.%09ld, sequence: %ld - "
+		gpsd_report(LOG_PROG, "KPPS assert %ld.%09ld, sequence: %ld - "
 		       "clear  %ld.%09ld, sequence: %ld\n",
 		       pi.assert_timestamp.tv_sec,
 		       pi.assert_timestamp.tv_nsec,
@@ -691,7 +704,7 @@ static /*@null@*/ void *gpsd_ppsmonitor(void *arg)
 	    break;
 	/*@ -ignoresigns */
 
-	state = (int)((state & pps_device) != 0);
+	state = (int)((state & PPS_LINE_TIOC) != 0);
 	/*@ +boolint @*/
 #define timediff(x, y)	(int)((x.tv_sec-y.tv_sec)*1000000+x.tv_usec-y.tv_usec)
 	cycle = timediff(tv, pulse[state]);
@@ -706,7 +719,7 @@ static /*@null@*/ void *gpsd_ppsmonitor(void *arg)
 		unchanged = 0;
 		gpsd_report(LOG_RAW,
 			    "PPS pps-detect (%s) on %s invisible pulse\n",
-			    pps_device_str, session->gpsdata.dev.path);
+			    PPS_LINE_NAME, session->gpsdata.dev.path);
 	    } else if (++unchanged == 10) {
 		unchanged = 1;
 		gpsd_report(LOG_WARN,
@@ -715,7 +728,7 @@ static /*@null@*/ void *gpsd_ppsmonitor(void *arg)
 	    }
 	} else {
 	    gpsd_report(LOG_RAW, "PPS pps-detect (%s) on %s changed to %d\n",
-			pps_device_str, session->gpsdata.dev.path, state);
+			PPS_LINE_NAME, session->gpsdata.dev.path, state);
 	    laststate = state;
 	    unchanged = 0;
 	}
@@ -724,7 +737,7 @@ static /*@null@*/ void *gpsd_ppsmonitor(void *arg)
 	    // strange, try again
 	    continue;
 	}
-	gpsd_report(LOG_INF, "PPS  cycle: %7d, duration: %7d @ %lu.%06lu\n",
+	gpsd_report(LOG_INF, "PPS cycle: %7d, duration: %7d @ %lu.%06lu\n",
 		    cycle, duration,
 		    (unsigned long)tv.tv_sec, (unsigned long)tv.tv_usec);
 
@@ -755,6 +768,7 @@ static /*@null@*/ void *gpsd_ppsmonitor(void *arg)
 	     *
 	     */
 
+	    log = "Unknown error";
 	    if (199000 > cycle) {
 		// too short to even be a 5Hz pulse
 		log = "Too short for 5Hz\n";
@@ -773,34 +787,34 @@ static /*@null@*/ void *gpsd_ppsmonitor(void *arg)
 		/* looks like PPS pulse or square wave */
 		if (0 == duration) {
 		    ok = 1;
-		    log = "PPS invisible pulse\n";
+		    log = "invisible pulse\n";
 		} else if (499000 > duration) {
 		    /* end of the short "half" of the cycle */
 		    /* aka the trailing edge */
-		    log = "PPS 1Hz trailing edge\n";
+		    log = "1Hz trailing edge\n";
 		} else if (501000 > duration) {
 		    /* looks like 1.0 Hz square wave, ignore trailing edge */
 		    if (state == 1) {
 			ok = 1;
-			log = "PPS square\n";
+			log = "square\n";
 		    }
 		} else {
 		    /* end of the long "half" of the cycle */
 		    /* aka the leading edge */
 		    ok = 1;
-		    log = "PPS 1Hz leading edge\n";
+		    log = "1Hz leading edge\n";
 		}
 	    } else if (1999000 > cycle) {
 		log = "Too long for 1Hz, too short for 2Hz\n";
 	    } else if (2001000 > cycle) {
 		/* looks like 0.5 Hz square wave */
 		if (999000 > duration) {
-		    log = "PPS 0.5 Hz square too short duration\n";
+		    log = "0.5 Hz square too short duration\n";
 		} else if (1001000 > duration) {
 		    ok = 1;
-		    log = "PPS 0.5 Hz square wave\n";
+		    log = "0.5 Hz square wave\n";
 		} else {
-		    log = "PPS 0.5 Hz square too long duration\n";
+		    log = "0.5 Hz square too long duration\n";
 		}
 	    } else {
 		log = "Too long for 0.5Hz\n";
@@ -808,13 +822,11 @@ static /*@null@*/ void *gpsd_ppsmonitor(void *arg)
 	} else {
 	    /* not a good fix, but a test for an otherwise good PPS
 	     * would go here */
-	    log = "PPS no fix.\n";
+	    log = "no fix.\n";
 	}
 	/*@ -boolint @*/
-	if (NULL != log) {
-	    gpsd_report(LOG_RAW, "%.100s", log);
-	}
 	if (0 != ok) {
+	    gpsd_report(LOG_RAW, "PPS edge accepted %.100s", log);
 	    /* chrony expects tv-sec since Jan 1970 */
 	    /* FIXME!! offset is double of the error from local time */
 	    sample.pulse = 0;
@@ -852,7 +864,7 @@ static /*@null@*/ void *gpsd_ppsmonitor(void *arg)
 
 	    if ( 0 <= chronyfd ) {
 		(void)send(chronyfd, &sample, sizeof (sample), 0);
-		gpsd_report(LOG_RAW, "PPS chrony sock %lu.%06lu offset %.9f\n",
+		gpsd_report(LOG_RAW, "PPS edge accepted chrony sock %lu.%06lu offset %.9f\n",
 			    (unsigned long)sample.tv.tv_sec,
 			    (unsigned long)sample.tv.tv_usec,
 			    sample.offset);
@@ -860,11 +872,11 @@ static /*@null@*/ void *gpsd_ppsmonitor(void *arg)
 	    TSTOTV( &tv, &ts );
 	    (void)ntpshm_pps(session, &tv);
 	} else {
-	    gpsd_report(LOG_INF, "PPS edge rejected\n");
+	    gpsd_report(LOG_RAW, "PPS edge rejected %.100s", log);
 	}
 
     }
-
+    gpsd_report(LOG_PROG, "PPS gpsd_ppsmonitor exited???\n");
     return NULL;
 }
 /*@+mustfreefresh +type +unrecog@*/
